@@ -2,11 +2,12 @@
 
 use std::{iter, str::from_utf8};
 
-use colors_transform::{Color, Rgb};
+use colorsys::Rgb;
 use std::os::unix::fs::PermissionsExt;
 use std::path::Path;
 use std::{fs, io};
 use strip_ansi_escapes::strip;
+use unicode_width::UnicodeWidthStr;
 use zellij_tile::data::{Palette, PaletteColor, PaletteSource, ThemeHue};
 
 const UNIX_PERMISSIONS: u32 = 0o700;
@@ -18,10 +19,7 @@ pub fn set_permissions(path: &Path) -> io::Result<()> {
 }
 
 pub fn ansi_len(s: &str) -> usize {
-    from_utf8(&strip(s.as_bytes()).unwrap())
-        .unwrap()
-        .chars()
-        .count()
+    from_utf8(&strip(s).unwrap()).unwrap().width()
 }
 
 pub fn adjust_to_size(s: &str, rows: usize, columns: usize) -> String {
@@ -51,13 +49,21 @@ pub mod colors {
     pub const RED: u8 = 88;
     pub const ORANGE: u8 = 166;
     pub const BLACK: u8 = 16;
+    pub const MAGENTA: u8 = 201;
+    pub const CYAN: u8 = 51;
+    pub const YELLOW: u8 = 226;
+    pub const BLUE: u8 = 45;
+    pub const PURPLE: u8 = 99;
+    pub const GOLD: u8 = 136;
+    pub const SILVER: u8 = 245;
+    pub const PINK: u8 = 207;
+    pub const BROWN: u8 = 215;
 }
 
 pub fn _hex_to_rgb(hex: &str) -> (u8, u8, u8) {
-    let rgb = Rgb::from_hex_str(hex)
+    Rgb::from_hex_str(hex)
         .expect("The passed argument must be a valid hex color")
-        .as_tuple();
-    (rgb.0 as u8, rgb.1 as u8, rgb.2 as u8)
+        .into()
 }
 
 pub fn default_palette() -> Palette {
@@ -69,12 +75,18 @@ pub fn default_palette() -> Palette {
         black: PaletteColor::EightBit(colors::BLACK),
         red: PaletteColor::EightBit(colors::RED),
         green: PaletteColor::EightBit(colors::GREEN),
-        yellow: PaletteColor::EightBit(colors::GRAY),
-        blue: PaletteColor::EightBit(colors::GRAY),
-        magenta: PaletteColor::EightBit(colors::GRAY),
-        cyan: PaletteColor::EightBit(colors::GRAY),
+        yellow: PaletteColor::EightBit(colors::YELLOW),
+        blue: PaletteColor::EightBit(colors::BLUE),
+        magenta: PaletteColor::EightBit(colors::MAGENTA),
+        cyan: PaletteColor::EightBit(colors::CYAN),
         white: PaletteColor::EightBit(colors::WHITE),
         orange: PaletteColor::EightBit(colors::ORANGE),
+        gray: PaletteColor::EightBit(colors::GRAY),
+        purple: PaletteColor::EightBit(colors::PURPLE),
+        gold: PaletteColor::EightBit(colors::GOLD),
+        silver: PaletteColor::EightBit(colors::SILVER),
+        pink: PaletteColor::EightBit(colors::PINK),
+        brown: PaletteColor::EightBit(colors::BROWN),
     }
 }
 
